@@ -30,7 +30,7 @@ Weather::MOSMIX::Writer - Write MOSMIX weather forecast data to a DBI handle
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # This should be MooX::Role::DBConnection
 with 'MooX::Role::DBIConnection';
@@ -134,8 +134,8 @@ sub create_db( $self, %options ) {
         %options,
     );
     if( ref $self ) {
-        $self->{dbh} = $dbh      # our dbh is generally read-only
-            unless $self->{dbh}; # we look directly so the lazy builder doesn't kick in
+        $self->{_dbh} = $dbh      # our dbh is generally read-only
+            unless $self->{_dbh}; # we look directly so the lazy builder doesn't kick in
     };
     return $dbh
 }
